<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv_SE">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../gui/aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>CallListener</name>
    <message>
        <source>Searching...</source>
        <translation>Söker...</translation>
    </message>
    <message>
        <source>Request timed out</source>
        <translation>Begäran tog för lång tid</translation>
    </message>
    <message>
        <source>Searching failed:</source>
        <translation>Sökningen misslyckades:</translation>
    </message>
    <message>
        <source>Phone number was not found</source>
        <translation>Telefonnumret hittades ej</translation>
    </message>
    <message>
        <source>Automatic connecting is not allowed by settings.</source>
        <translation>Automatisk anslutning är inte aktiverat, ändring i inställningarna krävs.</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Ansluter...</translation>
    </message>
    <message>
        <source>No available 3G or WLAN networks found.</source>
        <translation>Varken 3G- eller WLAN-nät kan användas.</translation>
    </message>
    <message>
        <source>Selected access point doesn&apos;t exist.</source>
        <translation>Vald accesspunkt kan ej hittas.</translation>
    </message>
    <message>
        <source>Unable to connect to network.</source>
        <translation>Kan ej ansluta till nätverket.</translation>
    </message>
</context>
<context>
    <name>ConnectionSelector</name>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="69"/>
        <source>Use global setting</source>
        <translation>Använd global inställning</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="70"/>
        <source>WLAN connection</source>
        <translation>WLAN-anslutning</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="71"/>
        <source>GPRS connection</source>
        <translation>GPRS-anslutning</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="72"/>
        <source>Any connection</source>
        <translation>Alla anslutningar</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="42"/>
        <location filename="../../gui/detailwindow.cpp" line="119"/>
        <source>Add to contacts</source>
        <translation>Lägg till kontakt</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="43"/>
        <source>Copy number to clipboard</source>
        <translation>Kopiera nummer</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="44"/>
        <source>Call</source>
        <translation>Ring</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="45"/>
        <source>Send SMS</source>
        <translation>Skicka SMS</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="53"/>
        <location filename="../../gui/detailwindow.cpp" line="122"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="54"/>
        <source>Street</source>
        <translation>Gata</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="55"/>
        <source>City</source>
        <translation>Stad</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="57"/>
        <source>Phone number</source>
        <translation>Telefonnummer</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <source>Unable make call</source>
        <translation>Kan ej starta samtal</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="123"/>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="156"/>
        <source>Contact was successfully added to contacts.</source>
        <translation>Kontakten lades till.i kontaktlistan.</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="194"/>
        <source>Unable to open SMS application</source>
        <translation>Kan ej öppna SMS-applikation</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <location filename="../../gui/detailwindow.cpp" line="160"/>
        <location filename="../../gui/detailwindow.cpp" line="194"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="160"/>
        <source>Unable to add contact.</source>
        <translation>Kunde ej lägga till kontakt.</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="170"/>
        <source>Number was successfully copied to clipboard.</source>
        <translation>Numret kopierades.</translation>
    </message>
</context>
<context>
    <name>EmptyGuiConfig</name>
    <message>
        <location filename="../../gui/emptyguiconfig.cpp" line="27"/>
        <source>Selected phonebook has no settings to configure.</source>
        <translation>Vald telefonkatalog har inga inställningar.</translation>
    </message>
</context>
<context>
    <name>EniroGuiConfig</name>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="36"/>
        <source>Eniro username</source>
        <translation>Eniro-användarnamn</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="39"/>
        <source>Eniro password</source>
        <translation>Eniro-lösenord</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="45"/>
        <source>Eniro site</source>
        <translation>Eniro-sida</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="57"/>
        <source>Finnish</source>
        <translation>Finska</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="60"/>
        <source>Swedish</source>
        <translation>Svenska</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="63"/>
        <source>Danish</source>
        <translation>Danska</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../../gui/logwindow.cpp" line="30"/>
        <source>Incoming call log</source>
        <translation>Samtalshistorik</translation>
    </message>
    <message>
        <location filename="../../gui/logwindow.cpp" line="31"/>
        <source>Clear log</source>
        <translation>Nollställ samtalshistorik</translation>
    </message>
    <message>
        <location filename="../../gui/logwindow.cpp" line="64"/>
        <source>There are currently no logged calls</source>
        <translation>Samtalshistoriken är tom</translation>
    </message>
    <message>
        <location filename="../../gui/logwindow.cpp" line="134"/>
        <source>%1 (no search results)</source>
        <translation>%1 (inget sökresultat)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="48"/>
        <source>Jenirok</source>
        <translation>Jenirok</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="54"/>
        <location filename="../../gui/mainwindow.cpp" line="151"/>
        <source>Stop daemon</source>
        <translation>Avaktivera</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="60"/>
        <location filename="../../gui/mainwindow.cpp" line="117"/>
        <source>Start daemon</source>
        <translation>Aktivera</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="65"/>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="76"/>
        <source>Log</source>
        <translation>Historik</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="82"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="83"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="115"/>
        <source>Daemon was successfully stopped.</source>
        <translation>Bakrundsprogrammet stoppades.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="116"/>
        <source>Unable to stop daemon.</source>
        <translation>Bakrundsprogrammet kunde ej stoppas.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="127"/>
        <source>Unable to start daemon</source>
        <translation>Kunde ej starta bakrundsprogrammet</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="129"/>
        <source>Daemon cannot be started because it&apos;s not allowed to connect to the Internet. You have to either allow automatic Internet connection in Jenirok settings or in global Maemo settings.</source>
        <translation>Bakrundsprogrammet kan ej startas eftersom det inte tillåts att ansluta till Internet. Du måste antingen tillåta automatisk Internetanslutning i Jenirok-inställningarna eller i de globala Maemo-inställningarna.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="133"/>
        <source>Open settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="135"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="149"/>
        <source>Daemon was successfully started.</source>
        <translation>Bakrundsprogrammet startades.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="150"/>
        <source>Unable to start daemon.</source>
        <translation>Kunde ej starta bakrundsprogrammet.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="157"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="181"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="181"/>
        <source>You need to set login details or other options in settings before using this feature.</source>
        <translation>Du måste ange inloggningsdetaljer eller andra inställningar först.</translation>
    </message>
</context>
<context>
    <name>ResultWindow</name>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="36"/>
        <source>Search results</source>
        <translation>Sökresultat</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="163"/>
        <source>Connection to server failed</source>
        <translation>Kontakt med server misslyckades</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="166"/>
        <source>Invalid login details</source>
        <translation>Felaktiga inloggningsuppgifter</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="169"/>
        <source>Request timed out</source>
        <translation>Begäran tog för lång tid</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="172"/>
        <source>Searching failed:</source>
        <translation>Sökningen misslyckades:</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="176"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="181"/>
        <source>No results found</source>
        <translation>Inget resultat</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="30"/>
        <location filename="../../gui/searchdialog.cpp" line="55"/>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="33"/>
        <source>Name/number</source>
        <translation>Namn/nummer</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="39"/>
        <source>Location</source>
        <translation>Plats</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="44"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="45"/>
        <source>Persons</source>
        <translation>Personer</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="46"/>
        <source>Companies</source>
        <translation>Företag</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="168"/>
        <source>fi</source>
        <translation>se</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="44"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="58"/>
        <source>Cache size (numbers)</source>
        <translation>Cache storlek (nummer)</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="61"/>
        <source>Clear</source>
        <translation>Nollställ</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="64"/>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="65"/>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="82"/>
        <source>Phonebook</source>
        <translation>Telefonkatalog</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="102"/>
        <source>Autostart</source>
        <translation>Starta automatiskt</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="104"/>
        <source>Enabled</source>
        <translation>Aktiverad</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="105"/>
        <source>Disabled</source>
        <translation>Avaktiverad</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="108"/>
        <source>Connect automatically on</source>
        <translation>Automatisk anslutning är på</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="112"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="137"/>
        <source>General</source>
        <translation>Generellt</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="138"/>
        <source>Daemon</source>
        <translation>Bakrundsprogram</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="139"/>
        <location filename="../../gui/settingsdialog.cpp" line="208"/>
        <source>Phonebook settings</source>
        <translation>Telefonkatalog</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="170"/>
        <source>Restarting daemon...</source>
        <translation>Startar om bakrundsprogram...</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="176"/>
        <source>You need to restart Jenirok for language change to take effect.</source>
        <translation>Du måste starta om Jenirok för att språkändring ska gälla.</translation>
    </message>
    <message numerus="yes">
        <location filename="../../gui/settingsdialog.cpp" line="188"/>
        <source>%n number(s) were deleted from cache</source>
        <translation>
            <numerusform>%n nummer raderat</numerusform>
            <numerusform>%n nummer raderades</numerusform>
        </translation>
    </message>
</context>
</TS>
